==> kdepim4_4.14.10.orig.tar.xz: kdepim-4.14.10/mailcommon/filter/autotests/filteractionsetstatustest.cpp <==
/*
  Copyright (c) 2015 Montel Laurent <montel@kde.org>

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License, version 2, as
  published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "filteractionsetstatustest.h"
#include "../filteractions/filteractionsetstatus.h"
#include <QWidget>
#include <qtest_kde.h>
#include <widgets/minimumcombobox.h>

FilterActionSetStatusTest::FilterActionSetStatusTest(QObject *parent)
    : QObject(parent)
{

}

FilterActionSetStatusTest::~FilterActionSetStatusTest()
{

}

void FilterActionSetStatusTest::shouldHaveDefaultValue()
{
    MailCommon::FilterActionSetStatus filter;
    QWidget *w = filter.createParamWidget(0);
    QCOMPARE(w->objectName(), QLatin1String("combobox"));
    PimCommon::MinimumComboBox *comboBox = dynamic_cast<PimCommon::MinimumComboBox *>(w);
    QVERIFY(comboBox);
    QVERIFY(!comboBox->isEditable());
    QVERIFY(comboBox->count()>0);
}

void FilterActionSetStatusTest::shouldHaveSieveRequires()
{
    MailCommon::FilterActionSetStatus filter;
    QCOMPARE(filter.sieveRequires(), QStringList() << QLatin1String("imap4flags"));
}

void FilterActionSetStatusTest::shouldBeEmpty()
{
    MailCommon::FilterActionSetStatus filter;
    QVERIFY(filter.isEmpty());
}

void FilterActionSetStatusTest::shouldRequiresPart()
{
    MailCommon::FilterActionSetStatus filter;
    QCOMPARE(filter.requiredPart(), MailCommon::SearchRule::Envelope);
}

QTEST_KDEMAIN(FilterActionSetStatusTest, GUI)

==> kdepim_15.08.2.orig.tar.xz: kdepim-15.08.2/mailcommon/filter/autotests/filteractionsetstatustest.cpp <==
/*
  Copyright (c) 2015 Montel Laurent <montel@kde.org>

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License, version 2, as
  published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "filteractionsetstatustest.h"
#include "../filteractions/filteractionsetstatus.h"
#include <qtest.h>
#include <QWidget>
#include <widgets/minimumcombobox.h>

FilterActionSetStatusTest::FilterActionSetStatusTest(QObject *parent)
    : QObject(parent)
{

}

FilterActionSetStatusTest::~FilterActionSetStatusTest()
{

}

void FilterActionSetStatusTest::shouldHaveDefaultValue()
{
    MailCommon::FilterActionSetStatus filter;
    QWidget *w = filter.createParamWidget(0);
    QCOMPARE(w->objectName(), QStringLiteral("combobox"));
    PimCommon::MinimumComboBox *comboBox = dynamic_cast<PimCommon::MinimumComboBox *>(w);
    QVERIFY(comboBox);
    QVERIFY(!comboBox->isEditable());
    QVERIFY(comboBox->count() > 0);
}

void FilterActionSetStatusTest::shouldHaveSieveRequires()
{
    MailCommon::FilterActionSetStatus filter;
    QCOMPARE(filter.sieveRequires(), QStringList() << QStringLiteral("imap4flags"));
}

void FilterActionSetStatusTest::shouldBeEmpty()
{
    MailCommon::FilterActionSetStatus filter;
    QVERIFY(filter.isEmpty());
}

void FilterActionSetStatusTest::shouldRequiresPart()
{
    MailCommon::FilterActionSetStatus filter;
    QCOMPARE(filter.requiredPart(), MailCommon::SearchRule::Envelope);
}

QTEST_MAIN(FilterActionSetStatusTest)
